.. py:currentmodule:: rubin_scheduler.site_models

.. _site-models:

===========
Site Models
===========

The `rubin_scheduler.site_models` module provides tools to read the simulated site weather data (seeing and cloud)
and provide those to the scheduler in a manner useful for the simulation (including adding airmass
and wavelength effects to the seeing, etc.). It also generates and reads back almanac information, such
as the sunrise and sunset times and planetary positions over the expected lifetime of LSST.

